@@ -10,6 +10,26 @@ def test_list_properties():
     assert response['data'][0].get('address')
 
 
+def test_list_properties_filter_text():
+    # Filter by Property Name
+    pass
+
+
+def test_list_properties_filter_group():
+    # Filter by Portfolio
+    pass
+
+
+def test_list_properties_filter_class():
+    # Filter by Property Type
+    pass
+
+
+def test_list_properties_filter_owner():
+    # Filter by Property Owner
+    pass
+
+
 def test_retrieve_property():
     response = dl.properties.list(query_params={'page_size': 100})
     assert isinstance(response, dict)
